@@ -2,7 +2,7 @@ package Text::Minify::XS;
 
 # ABSTRACT: Simple text minification
 
-use v5.6;
+use v5.9.3;
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ require XSLoader;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(minify);
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 XSLoader::load( "Text::Minify::XS", $VERSION );
 
@@ -30,7 +30,7 @@ Text::Minify::XS - Simple text minification
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
@@ -61,7 +61,7 @@ It does the following:
 
 =back
 
-It does not know recognise any form of markup, comments or text quoting.
+It does not recognise any form of markup, comments or text quoting.
 
 =head1 KNOWN ISSUES
 
